@@ -1,4 +1,4 @@
-use Perlmazing;
+use Perlmazing qw(_is_ref);
 
 sub main ($) {
 	_is_ref('FORMAT', $_[0]);
