@@ -3,12 +3,18 @@ use Perlmazing qw(croak);
 sub main {
 	my $file = shift;
 	my $binary = shift;
-	local $/ = undef;
 	croak "File '$file' cannot be read: $!" unless open my $in, '<', $file;
 	binmode $in if -B $file or $binary;
-	my $data = <$in>;
-	close $in;
-	$data;
+  if (wantarray) {
+    my @data = <$in>;
+    close $in;
+    return @data;
+  } else {
+    local $/ = undef;
+    my $data = <$in>;
+    close $in;
+    return $data;
+  }
 }
 
 1;
\ No newline at end of file
